<?php

namespace Drupal\hubspot_api;

use HubSpot\Discovery\Discovery;

/**
 * Provides an interface for the HubSpot API Manager.
 */
interface ManagerInterface {

  /**
   * Creates the Factory object that will be used to make api calls.
   *
   * Try to use OAuth. If it's not set, try to use Private App access token.
   *
   * @return \HubSpot\Discovery\Discovery|null
   *   The factory object or NULL.
   *
   * @throws \Exception
   */
  public function getHandler(): ?Discovery;

  /**
   * Creates the Factory object with OAuth.
   *
   * @return \HubSpot\Discovery\Discovery|null
   *   The factory object or NULL.
   *
   * @throws \Exception
   */
  public function getHandlerWithOauth(): ?Discovery;

  /**
   * Creates the Factory object with Private App access token.
   *
   * @param string|null $token
   *   The Private App access token.
   *
   * @return \HubSpot\Discovery\Discovery|null
   *   The factory object or NULL.
   *
   * @throws \Exception
   */
  public function getHandlerWithAccessToken(string $token = NULL): ?Discovery;

}
